@@ -6,7 +6,7 @@ from pypsql_api.config.types import Session
 from pypsql_api.wire.actions_types import Names
 from pypsql_api.context import Context
 from pypsql_api.wire.back import SSLNo, AuthenticationCleartextPassword, ReadyForQuery, AuthenticationOk, \
-    EmptyQueryResponse, DataFrameRowDescription, DataFrameDataRows, CommandComplete, SSLYes
+    EmptyQueryResponse, DataFrameRowDescription, DataFrameDataRows, CommandComplete, SSLYes, ErrorResponse
 from pypsql_api.wire.bytes import ReadingIO, WritingIO
 from pypsql_api.wire.errors.core import log_exception, NoData
 from pypsql_api.wire.front import SSLRequest, StartupMessage, Message, PasswordMessage
@@ -102,13 +102,13 @@ def read_plain_text_password_request(context: Context):
 
     session = context.session
     session.password = m.password
-    print(f"Got password {m.password}")
     auth_ok, msg = context.auth_handler.handle(session=session)
 
     if auth_ok:
         return context, Names.WRITE_AUTH_OK
     else:
-        raise Exception(f"Password not correct {msg}")
+        ErrorResponse.severe("Password not correct").write(context.output)
+        return context, Names.CLOSE
 
 
 def write_ready_for_query(context: Context):
